AtAuth class abstract interface

Interface for onboarding and authentication to a secondary server of an atsign

Constructors

AtAuth.create({AtLookUp? atLookUp, AtChops? atChops, CramAuthenticator? cramAuthenticator, PkamAuthenticator? pkamAuthenticator, AtEnrollment? atEnrollmentBase})
factory

Properties

atChops ↔ AtChops?
getter/setter pair
atLookUp ↔ AtLookUp?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
progressStream Stream<ProgressEvent>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate(AtAuthRequest atAuthRequest) Future<AtAuthResponse>
Authenticate method is invoked when an atsign wants to authenticate to secondary server with an .atKeys file
completeActivation() Future<void>
  • Update encryption public key to server
  • Delete cram secret from server
  • noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    onboard(AtOnboardingRequest atOnboardingRequest, String cramSecret, {bool autoCompleteActivation = true}) Future<AtOnboardingResponse>
    Onboard method is invoked when an atsign is activated for the first time from a client app.
    toString() String
    A string representation of this object.
    inherited
    validateAtServer(AuthRequest authRequest) Future<void>
    Validate atsign's secondary server status

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited