decodeAtKeys method

  1. @Deprecated('legacy helpers for serialization, if we need to retain this turn it into a static helper')
Future<Map<String, dynamic>> decodeAtKeys(
  1. Map<String, dynamic> decodedAtKeysData, {
  2. String? passPhrase,
})

Implementation

@Deprecated(
    'legacy helpers for serialization, if we need to retain this turn it into a static helper')
Future<Map<String, dynamic>> decodeAtKeys(
    Map<String, dynamic> decodedAtKeysData,
    {String? passPhrase}) {
  return passphraseCodec.decode(decodedAtKeysData, passPhrase: passPhrase);
}