AtEnrollmentRecord class abstract
Base class for enrollment-related data objects.
Provides a unified interface for accessing enrollmentId and enrollmentStatus across both server-side enrollment details (ServerEnrollmentRequest) and enrollment operation results (AtEnrollmentResponse).
- Implementers
Constructors
Properties
- enrollmentId → String
-
no setter
- enrollmentStatus → EnrollmentStatus
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited