NamespacePermission class
Model class representing a namespace permission.
The string representation of the permission is namespace: {ns1: rw, ns2: r}
where read is r and write is w and ns1/ns2 are the namespaces.
- Annotations
-
- @immutable
Constructors
- NamespacePermission({required String namespace, bool read = false, bool write = false})
-
Model class representing a namespace permission.
The string representation of the permission is
namespace: {ns1: rw, ns2: r}where read isrand write iswandns1/ns2are the namespaces.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- namespace → String
-
The namespace that the permission applies to.
final
- read → bool
-
Whether the app/device has read access to the namespace.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- write → bool
-
Whether the app/device has write access to the namespace.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override