FileAtKeysIo class
File-backed .atKeys storage.
- Inheritance
-
- Object
- AtKeysIo
- WrittenAtKeysIo
- FileAtKeysIo
Constructors
- FileAtKeysIo({String filePath(String)?, String? passPhrase})
Properties
- assurance → AtKeysAssurance
-
finalinherited
- filePath ↔ String Function(String)?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- passPhrase ↔ String?
-
getter/setter pair
- passphraseCodec → AtKeysPassphraseEnvelopeCodec
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeAtKeys(
Map< String, dynamic> decodedAtKeysData, {String? passPhrase}) → Future<Map< String, dynamic> > -
inherited
-
decryptAtKeysWithSelfEncKey(
Map< String, dynamic> jsonData, PkamAuthMode authMode) → Future<AtKeys> -
inherited
-
encryptAtKeysWithSelfEncKey(
AtKeys atKeys, PkamAuthMode authMode, String atsign) → Future< String> -
inherited
-
flush(
Atsign atsign, AtKeys atKeys) → Future< void> -
Persists
atKeysas the complete new state foratsign.override -
generateKeyPairs(
{PkamAuthMode authMode = PkamAuthMode.keysFile}) → AtKeys -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String atsign) → Future< AtKeys> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Atsign atsign, FutureOr< bool> mutate(AtKeys keys)) → Future<void> -
Read, mutate and write inside one hold of the lock.
override
-
write(
String atsign, AtKeys atKeys) → Future -
Create-only initial persist (fresh onboard); implementations throw if
the target already exists. Use flush to persist later mutations.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited